@@ -2,14 +2,26 @@ from typing import Any, Optional
 
 import click
 
-from .cli_utils import is_verbose
+from .cli_utils import is_verbose, no_ansi
+
+
+def style(msg: str, fg: str, bold: bool) -> str:
+    """
+    Styles a text with ANSI styles and returns the new string
+
+    If the --no-ansi flag was passed, no styles are applied
+    """
+    if no_ansi():
+        return msg
+    else:
+        return click.style(msg, fg=fg, bold=bold)
 
 
 def secho(msg: Any, fg: str, bold: bool = False) -> None:
     """Similar to click.secho"""
-    if not isinstance(msg, str):
+    if not isinstance(msg, (str, bytes)):
         msg = str(msg)
-    click.echo(click.style(msg, fg=fg, bold=bold))
+    click.echo(style(msg, fg=fg, bold=bold))
 
 
 def warning(msg: Any) -> None:
@@ -27,21 +39,26 @@ def info(msg: Any) -> None:
     secho(msg, "blue")
 
 
-def debug(msg: Any) -> None:
+def log(msg: Any) -> None:
     """click.echo in a white color"""
+    secho(msg, "white")
+
+
+def debug(msg: Any) -> None:
+    """click.echo in a white color, only if the --verbose flag was set"""
     if is_verbose():
-        secho(msg, "white", bold=False)
+        log(msg)
 
 
 def prompt(
     text: str, hide_input: bool = False, fg: str = "cyan", default: Any = None, type: Optional[click.ParamType] = None
 ) -> Any:
     """Ask the user to enter a value, and return the result"""
-    text = click.style(text, fg=fg, bold=True)
+    text = style(text, fg=fg, bold=True)
     return click.prompt(text, hide_input=hide_input, default=default, type=type)
 
 
 def confirm(text: str, default: bool = True, fg: str = "cyan") -> bool:
     """Ask the user for confirmation and return the bool result"""
-    text = click.style(text, fg=fg, bold=True)
+    text = style(text, fg=fg, bold=True)
     return click.confirm(text, default=default)
